@@ -17,7 +17,6 @@ modules = [
     "4chan",
     "500px",
     "8chan",
-    "8kun",
     "8muses",
     "adultempire",
     "architizer",
@@ -143,6 +142,7 @@ modules = [
     "twitter",
     "unsplash",
     "vanillarock",
+    "vichan",
     "vk",
     "vsco",
     "wallhaven",
@@ -152,7 +152,6 @@ modules = [
     "webtoons",
     "weibo",
     "wikiart",
-    "wikieat",
     "xhamster",
     "xvideos",
     "zerochan",
