@@ -33,6 +33,7 @@ class KemonopartyExtractor(Extractor):
             self.cookiedomain = ".coomer.party"
         self.root = text.root_from_url(match.group(0))
         Extractor.__init__(self, match)
+        self.session.headers["Referer"] = self.root + "/"
 
     def items(self):
         self._prepare_ddosguard_cookies()
@@ -46,7 +47,7 @@ class KemonopartyExtractor(Extractor):
         comments = self.config("comments")
         username = dms = None
 
-        # prevent files to be sent with gzip compression
+        # prevent files from being sent with gzip compression
         headers = {"Accept-Encoding": "identity"}
 
         if self.config("metadata"):
@@ -63,6 +64,9 @@ class KemonopartyExtractor(Extractor):
 
         for post in posts:
 
+            headers["Referer"] = "{}/{}/user/{}/post/{}".format(
+                self.root, post["service"], post["user"], post["id"])
+            post["_http_headers"] = headers
             post["date"] = text.parse_datetime(
                 post["published"] or post["added"],
                 "%a, %d %b %Y %H:%M:%S %Z")
@@ -74,27 +78,33 @@ class KemonopartyExtractor(Extractor):
                 if dms is True:
                     dms = self._extract_dms(post)
                 post["dms"] = dms
-            yield Message.Directory, post
 
+            files = []
             hashes = set()
-            post["num"] = 0
+
             for file in itertools.chain.from_iterable(
                     g(post) for g in generators):
                 url = file["path"]
 
                 match = find_hash(url)
                 if match:
-                    post["hash"] = hash = match.group(1)
+                    file["hash"] = hash = match.group(1)
                     if hash in hashes and not duplicates:
                         self.log.debug("Skipping %s (duplicate)", url)
                         continue
                     hashes.add(hash)
                 else:
-                    post["hash"] = ""
+                    file["hash"] = ""
 
+                files.append(file)
+
+            post["count"] = len(files)
+            yield Message.Directory, post
+
+            for post["num"], file in enumerate(files, 1):
+                post["hash"] = file["hash"]
                 post["type"] = file["type"]
-                post["num"] += 1
-                post["_http_headers"] = headers
+                url = file["path"]
 
                 text.nameext_from_url(file.get("name", url), post)
                 if not post["extension"]:
@@ -180,7 +190,7 @@ class KemonopartyExtractor(Extractor):
         for dm in text.extract_iter(page, "<article", "</article>"):
             dms.append({
                 "body": text.unescape(text.extract(
-                    dm, '<pre>', '</pre></section>',
+                    dm, "<pre>", "</pre></",
                 )[0].strip()),
                 "date": text.extract(dm, 'datetime="', '"')[0],
             })
@@ -220,9 +230,10 @@ class KemonopartyUserExtractor(KemonopartyExtractor):
             posts = self.request(url, params=params).json()
             yield from posts
 
-            if len(posts) < 25:
+            cnt = len(posts)
+            if cnt < 25:
                 return
-            params["o"] += 25
+            params["o"] += cnt
 
 
 class KemonopartyPostExtractor(KemonopartyExtractor):
@@ -236,6 +247,7 @@ class KemonopartyPostExtractor(KemonopartyExtractor):
             "keyword": {
                 "added": "Wed, 06 May 2020 20:28:02 GMT",
                 "content": str,
+                "count": 1,
                 "date": "dt:2019-08-11 02:09:04",
                 "edited": None,
                 "embed": dict,
@@ -374,6 +386,7 @@ class KemonopartyDiscordExtractor(KemonopartyExtractor):
             post["channel_name"] = self.channel_name
             post["date"] = text.parse_datetime(
                 post["published"], "%a, %d %b %Y %H:%M:%S %Z")
+            post["count"] = len(files)
             yield Message.Directory, post
 
             for post["num"], file in enumerate(files, 1):
@@ -408,9 +421,10 @@ class KemonopartyDiscordExtractor(KemonopartyExtractor):
             posts = self.request(url, params=params).json()
             yield from posts
 
-            if len(posts) < 25:
+            cnt = len(posts)
+            if cnt < 25:
                 break
-            params["skip"] += 25
+            params["skip"] += cnt
 
 
 class KemonopartyDiscordServerExtractor(KemonopartyExtractor):
@@ -466,7 +480,7 @@ class KemonopartyFavoriteExtractor(KemonopartyExtractor):
 
         if self.favorites == "artist":
             users = self.request(
-                self.root + "/api/v1/account/favorites?type=artist").json()
+                self.root + "/api/favorites?type=artist").json()
             for user in users:
                 user["_extractor"] = KemonopartyUserExtractor
                 url = "{}/{}/user/{}".format(
@@ -475,7 +489,7 @@ class KemonopartyFavoriteExtractor(KemonopartyExtractor):
 
         elif self.favorites == "post":
             posts = self.request(
-                self.root + "/api/v1/account/favorites?type=post").json()
+                self.root + "/api/favorites?type=post").json()
             for post in posts:
                 post["_extractor"] = KemonopartyPostExtractor
                 url = "{}/{}/user/{}/post/{}".format(
