@@ -45,6 +45,7 @@ class PixivExtractor(Extractor):
                 work["tags"] = [tag["name"] for tag in work["tags"]]
 
         ratings = {0: "General", 1: "R-18", 2: "R-18G"}
+        userdata = self.config("metadata")
         metadata = self.metadata()
 
         works = self.works()
@@ -60,6 +61,8 @@ class PixivExtractor(Extractor):
             del work["image_urls"]
             del work["meta_pages"]
 
+            if userdata:
+                work.update(self.api.user_detail(work["user"]["id"]))
             if transform_tags:
                 transform_tags(work)
             work["num"] = 0
@@ -198,7 +201,7 @@ class PixivArtworksExtractor(PixivExtractor):
 
     def metadata(self):
         if self.config("metadata"):
-            return self.api.user_detail(self.user_id)
+            self.api.user_detail(self.user_id)
         return {}
 
     def works(self):
@@ -238,7 +241,7 @@ class PixivAvatarExtractor(PixivExtractor):
 class PixivBackgroundExtractor(PixivExtractor):
     """Extractor for pixiv background banners"""
     subcategory = "background"
-    filename_fmt = "background{date?_//:%Y-%m-%d}.{extension}"
+    filename_fmt = "background{date:?_//%Y-%m-%d}.{extension}"
     archive_fmt = "background_{user[id]}_{date}"
     pattern = (r"(?:https?://)?(?:www\.)?pixiv\.net"
                r"/(?:en/)?users/(\d+)/background")
@@ -557,7 +560,7 @@ class PixivSearchExtractor(PixivExtractor):
             sort = "date_d"
         self.sort = sort_map[sort]
 
-        target = query.get("s_mode", "s_tag")
+        target = query.get("s_mode", "s_tag_full")
         target_map = {
             "s_tag": "partial_match_for_tags",
             "s_tag_full": "exact_match_for_tags",
@@ -565,7 +568,7 @@ class PixivSearchExtractor(PixivExtractor):
         }
         if target not in target_map:
             self.log.warning("invalid search target '%s'", target)
-            target = "s_tag"
+            target = "s_tag_full"
         self.target = target_map[target]
 
         self.date_start = query.get("scd")
@@ -642,6 +645,66 @@ class PixivPixivisionExtractor(PixivExtractor):
         }
 
 
+class PixivSeriesExtractor(PixivExtractor):
+    """Extractor for illustrations from a Pixiv series"""
+    subcategory = "series"
+    directory_fmt = ("{category}", "{user[id]} {user[account]}",
+                     "{series[id]} {series[title]}")
+    filename_fmt = "{num_series:>03}_{id}_p{num}.{extension}"
+    pattern = (r"(?:https?://)?(?:www\.)?pixiv\.net"
+               r"/user/(\d+)/series/(\d+)")
+    test = ("https://www.pixiv.net/user/10509347/series/21859", {
+        "range": "1-10",
+        "count": 10,
+        "keyword": {
+            "num_series": int,
+            "series": {
+                "canonical": "https://www.pixiv.net/user/10509347"
+                             "/series/21859",
+                "description": str,
+                "ogp": dict,
+                "title": "先輩がうざい後輩の話",
+                "total": int,
+                "twitter": dict,
+            },
+        },
+    })
+
+    def __init__(self, match):
+        PixivExtractor.__init__(self, match)
+        self.user_id, self.series_id = match.groups()
+
+    def works(self):
+        url = self.root + "/ajax/series/" + self.series_id
+        params = {"p": 1}
+        headers = {
+            "Accept": "application/json",
+            "Referer": "{}/user/{}/series/{}".format(
+                self.root, self.user_id, self.series_id),
+            "Alt-Used": "www.pixiv.net",
+        }
+
+        while True:
+            data = self.request(url, params=params, headers=headers).json()
+            body = data["body"]
+            page = body["page"]
+
+            series = body["extraData"]["meta"]
+            series["id"] = self.series_id
+            series["total"] = page["total"]
+            series["title"] = text.extract(series["title"], '"', '"')[0]
+
+            for info in page["series"]:
+                work = self.api.illust_detail(info["workId"])
+                work["num_series"] = info["order"]
+                work["series"] = series
+                yield work
+
+            if len(page["series"]) < 10:
+                return
+            params["p"] += 1
+
+
 class PixivSketchExtractor(Extractor):
     """Extractor for user pages on sketch.pixiv.net"""
     category = "pixiv"
