@@ -19,15 +19,9 @@ class MetadataPP(PostProcessor):
     def __init__(self, job, options):
         PostProcessor.__init__(self, job)
 
-        mode = options.get("mode", "json")
-        if mode == "custom":
-            self.write = self._write_custom
-            cfmt = options.get("content-format") or options.get("format")
-            if isinstance(cfmt, list):
-                cfmt = "\n".join(cfmt) + "\n"
-            self._content_fmt = formatter.parse(cfmt).format_map
-            ext = "txt"
-        elif mode == "tags":
+        mode = options.get("mode")
+        cfmt = options.get("content-format") or options.get("format")
+        if mode == "tags":
             self.write = self._write_tags
             ext = "txt"
         elif mode == "modify":
@@ -41,6 +35,12 @@ class MetadataPP(PostProcessor):
             self.run = self._run_delete
             self.fields = options.get("fields")
             ext = None
+        elif mode == "custom" or not mode and cfmt:
+            self.write = self._write_custom
+            if isinstance(cfmt, list):
+                cfmt = "\n".join(cfmt) + "\n"
+            self._content_fmt = formatter.parse(cfmt).format_map
+            ext = "txt"
         else:
             self.write = self._write_json
             self.indent = options.get("indent", 4)
